/**
 * @file Ce fichier contient les tests des resolvers des groupes
 * @author ofacklam
*/

import { TestSet } from '../../testData';

export const tests : TestSet = {
    description: "Group type resolvers",
    tests: [
        {
            description: "group(gid) bad gid",
            query: `
            query {
                group(gid:"nonexistent") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "group": null
                }
            }
        },

        {
            description: "group(gid) with simplegroup",
            query: `
            query {
                group(gid:"br") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "gid": "br"
                    }
                } 
            }
        },

        {
            description: "group(gid) with uncached simplegroup",
            query: `
            query {
                group(gid:"bda") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "gid": "bda"
                    }
                }
            }
        },

        {
            description: "group(gid) with metagroup",
            query: `
            query {
                group(gid:"federez") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "gid": "federez"
                    }
                }
            }
        },

        {
            description: "simpleGroup(gid) bad gid",
            query: `
            query {
                simpleGroup(gid:"federez") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "simpleGroup": null
                }
            }
        },

        {
            description: "simpleGroup(gid)",
            query: `
            query {
                simpleGroup(gid:"br") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "simpleGroup": {
                        "gid": "br"
                    }
                }
            }
        },

        {
            description: "metaGroup(gid) bad gid",
            query: `
            query {
                metaGroup(gid:"br") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "metaGroup": null
                }
            }
        },

        {
            description: "metaGroup(gid)",
            query: `
            query {
                metaGroup(gid:"federez") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "metaGroup": {
                        "gid": "federez"
                    }
                }
            }
        },

        {
            description: "gid, name (SimpleGroup)",
            query: `
            query {
                group(gid:"br") {
                    gid
                    name
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "gid": "br",
                        "name": "Binet Réseau"
                    }
                }
            }
        },

        {
            description: "gid, name (uncached SimpleGroup)",
            query: `
            query {
                group(gid:"bda") {
                    gid
                    name
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "gid": "bda",
                        "name": "BDA"
                    }
                }
            }
        },

        {
            description: "gid, name (MetaGroup)",
            query: `
            query {
                group(gid:"federez") {
                    gid
                    name
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "gid": "federez",
                        "name": "Fédérez"
                    }
                }
            }
        }, 

        {
            description: "description, mail, website not authorized",
            query: `
            query {
                group(gid:"br") {
                    description
                    mail
                    website
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "description": null,
                        "mail": null,
                        "website": null
                    }
                }
            }
        },

        {
            description: "admins, frontPage, questions, answers not authorized",
            query: `
            query {
                group(gid: "br") {
                    admins {
                        givenName
                        lastName
                    }
                    frontPage
                    questions {
                        title
                        content
                        author {
                            givenName
                            lastName
                        }
                    }
                    answers {
                        title
                        content
                    }
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "admins": null,
                        "frontPage": null,
                        "questions": null,
                        "answers": null
                    }
                }
            }
        }
    ]
}
