/**
 * @file Ce fichier contient les tests des resolvers des groupes
 * @author ofacklam
*/

import { TestSet } from '../../testData';

export const tests: TestSet = {
    description: "Group type resolvers",
    tests: [
        {
            description: "description, mail, website (SimpleGroup)",
            query: `
            query {
                group(gid:"br") {
                    description
                    mail
                    website
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "description": "Le binet qui développe les outils informatiques nécessaires à la vie en campus et entretient le réseau élève !\r\n\r\nUn problème technique ? Une seule adresse : [[https://panix.binets.fr|panix.binets.fr]] \\\\\r\nPour ce qui concerne Frankiz, s'adresser aux [[https://www.frankiz.net/groups/see/webmasters|Web]] à l'adresse : web@frankiz.net",
                        "mail": "br@binets.fr",
                        "website": "http://br.binets.fr"
                    }
                }
            }
        },

        {
            description: "description, mail, website (uncached SimpleGroup)",
            query: `
            query {
                group(gid:"artificial_intelligence") {
                    description
                    mail
                    website
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "description": "Binet visant à réunir tous ceux qui sont intéressés par l'IA, et en particulier les réseaux de neurones. Propose des PSC à thématique IA en partenariat avec des acteurs du domaine.",
                        "mail": "artificial_intelligence@binets.fr",
                        "website": null
                    }
                }
            }
        },

        {
            description: "description, mail, website (MetaGroup)",
            query: `
            query {
                group(gid:"federez") {
                    description
                    mail
                    website
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "description": "L'association de toutes les associations de réseau des écoles",
                        "mail": null,
                        "website": "federez.io"
                    }
                }
            }
        },

        {
            description: "admins, frontPage, questions, answers (SimpleGroup)",
            query: `
            query {
                group(gid: "br") {
                    admins {
                        givenName
                        lastName
                    }
                    frontPage
                    questions {
                        title
                        content
                        author {
                            givenName
                            lastName
                        }
                    }
                    answers {
                        title
                        content
                    }
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "admins": [
                            {
                                "givenName": "Timothée",
                                "lastName": "Darcet"
                            },
                            {
                                "givenName": "Hadrien",
                                "lastName": "Renaud"
                            },
                            {
                                "givenName": "Thibault",
                                "lastName": "Juillard"
                            },
                            {
                                "givenName": "Alexis",
                                "lastName": "Baleras"
                            },
                            {
                                "givenName": "Grégoire",
                                "lastName": "Grzeczkowicz"
                            }
                        ],
                        "frontPage": "Le Binet Réseau est responsable du réseau internet des élèves sur le campus de l'Ecole polytechnique.",
                        "questions": [
                            {
                                "title": "Au secours !",
                                "content": "Quand sont les perms BR ? J'arrive pas a me connecter a eduroam :'(",
                                "author": {
                                    "givenName": "Olivér",
                                    "lastName": "Facklam"
                                }
                            }
                        ],
                        "answers": [
                            {
                                "title": "Perms BR",
                                "content": "Il y a des perms tous les mardis et jeudis de 19h a 20h ! N'hésite que peu a passer."
                            }
                        ]
                    }
                }
            }
        },

        {
            description: "admins, frontPage, questions, answers (uncached SimpleGroup)",
            query: `
            query {
                group(gid: "artificial_intelligence") {
                    admins {
                        givenName
                        lastName
                    }
                    frontPage
                    questions {
                        title
                        content
                        author {
                            givenName
                            lastName
                        }
                    }
                    answers {
                        title
                        content
                    }
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "admins": [
                            {
                                "givenName": "Charles",
                                "lastName": "Madeline-Dérou"
                            },
                            {
                                "givenName": "Léo",
                                "lastName": "Heidelberger"
                            },
                            {
                                "givenName": "Tristan",
                                "lastName": "Stampfler"
                            }
                        ],
                        "frontPage": null,
                        "questions": [],
                        "answers": []
                    }
                }
            }
        },

        {
            description: "admins, frontPage, questions, answers (MetaGroup)",
            query: `
            query {
                group(gid: "federez") {
                    admins {
                        givenName
                        lastName
                    }
                    frontPage
                    questions {
                        title
                        content
                        author {
                            givenName
                            lastName
                        }
                    }
                    answers {
                        title
                        content
                    }
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "admins": [
                            {
                                "givenName": "Timothée",
                                "lastName": "Darcet"
                            },
                            {
                                "givenName": "Hadrien",
                                "lastName": "Renaud"
                            },
                            {
                                "givenName": "Thibault",
                                "lastName": "Juillard"
                            },
                            {
                                "givenName": "Alexis",
                                "lastName": "Baleras"
                            },
                            {
                                "givenName": "Grégoire",
                                "lastName": "Grzeczkowicz"
                            }
                        ],
                        "frontPage": "Une belle string en markdown !",
                        "questions": [],
                        "answers": []
                    }
                }
            }
        },
        
    ]
}
